@@ -1,4 +1,4 @@
-/* $OpenBSD: ecparam.c,v 1.7 2014/12/28 14:21:42 jsing Exp $ */
+/* $OpenBSD: ecparam.c,v 1.8 2014/12/28 15:48:52 jsing Exp $ */
 /*
  * Written by Nils Larsch for the OpenSSL project.
  */
@@ -361,6 +361,9 @@ ecparam_main(int argc, char **argv)
 		} else
 			nid = OBJ_sn2nid(ecparam_config.curve_name);
 
+		if (nid == 0)
+			nid = EC_curve_nist2nid(ecparam_config.curve_name);
+
 		if (nid == 0) {
 			BIO_printf(bio_err, "unknown curve name (%s)\n",
 			    ecparam_config.curve_name);
