@@ -1,4 +1,4 @@
-/* $OpenBSD: speed.c,v 1.4 2015/01/03 03:03:39 lteo Exp $ */
+/* $OpenBSD: speed.c,v 1.5 2015/02/08 10:22:45 doug Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -124,9 +124,6 @@
 #ifndef OPENSSL_NO_IDEA
 #include <openssl/idea.h>
 #endif
-#ifndef OPENSSL_NO_MDC2
-#include <openssl/mdc2.h>
-#endif
 #ifndef OPENSSL_NO_MD4
 #include <openssl/md4.h>
 #endif
@@ -179,7 +176,7 @@ static int do_multi(int multi);
 #define MAX_ECDH_SIZE 256
 
 static const char *names[ALGOR_NUM] = {
-	"md2", "mdc2", "md4", "md5", "hmac(md5)", "sha1", "rmd160", "rc4",
+	"md2", "md4", "md5", "hmac(md5)", "sha1", "rmd160", "rc4",
 	"des cbc", "des ede3", "idea cbc", "seed cbc",
 	"rc2 cbc", "rc5-32/12 cbc", "blowfish cbc", "cast cbc",
 	"aes-128 cbc", "aes-192 cbc", "aes-256 cbc",
@@ -241,9 +238,6 @@ speed_main(int argc, char **argv)
 	long rsa_count;
 	unsigned rsa_num;
 	unsigned char md[EVP_MAX_MD_SIZE];
-#ifndef OPENSSL_NO_MDC2
-	unsigned char mdc2[MDC2_DIGEST_LENGTH];
-#endif
 #ifndef OPENSSL_NO_MD4
 	unsigned char md4[MD4_DIGEST_LENGTH];
 #endif
@@ -331,7 +325,6 @@ speed_main(int argc, char **argv)
 	CAMELLIA_KEY camellia_ks1, camellia_ks2, camellia_ks3;
 #endif
 #define	D_MD2		0
-#define	D_MDC2		1
 #define	D_MD4		2
 #define	D_MD5		3
 #define	D_HMAC		4
@@ -586,11 +579,6 @@ speed_main(int argc, char **argv)
 			j--;	/* Otherwise, -mr gets confused with an
 				 * algorithm. */
 		} else
-#ifndef OPENSSL_NO_MDC2
-		if (strcmp(*argv, "mdc2") == 0)
-			doit[D_MDC2] = 1;
-		else
-#endif
 #ifndef OPENSSL_NO_MD4
 		if (strcmp(*argv, "md4") == 0)
 			doit[D_MD4] = 1;
@@ -844,9 +832,6 @@ speed_main(int argc, char **argv)
 			BIO_printf(bio_err, "Error: bad option or value\n");
 			BIO_printf(bio_err, "\n");
 			BIO_printf(bio_err, "Available values:\n");
-#ifndef OPENSSL_NO_MDC2
-			BIO_printf(bio_err, "mdc2     ");
-#endif
 #ifndef OPENSSL_NO_MD4
 			BIO_printf(bio_err, "md4      ");
 #endif
@@ -871,7 +856,7 @@ speed_main(int argc, char **argv)
 #ifndef OPENSSL_NO_RIPEMD160
 			BIO_printf(bio_err, "rmd160");
 #endif
-#if !defined(OPENSSL_NO_MD2) || !defined(OPENSSL_NO_MDC2) || \
+#if !defined(OPENSSL_NO_MD2) || \
     !defined(OPENSSL_NO_MD4) || !defined(OPENSSL_NO_MD5) || \
     !defined(OPENSSL_NO_SHA1) || !defined(OPENSSL_NO_RIPEMD160) || \
     !defined(OPENSSL_NO_WHIRLPOOL)
@@ -1042,19 +1027,6 @@ speed_main(int argc, char **argv)
 #define COUNT(d) (count)
 	signal(SIGALRM, sig_done);
 
-#ifndef OPENSSL_NO_MDC2
-	if (doit[D_MDC2]) {
-		for (j = 0; j < SIZE_NUM; j++) {
-			print_message(names[D_MDC2], c[D_MDC2][j], lengths[j]);
-			Time_F(START);
-			for (count = 0, run = 1; COND(c[D_MDC2][j]); count++)
-				EVP_Digest(buf, (unsigned long) lengths[j], &(mdc2[0]), NULL, EVP_mdc2(), NULL);
-			d = Time_F(STOP);
-			print_result(D_MDC2, j, count, d);
-		}
-	}
-#endif
-
 #ifndef OPENSSL_NO_MD4
 	if (doit[D_MD4]) {
 		for (j = 0; j < SIZE_NUM; j++) {
