@@ -1,4 +1,4 @@
-/* $OpenBSD: s23_clnt.c,v 1.35 2014/12/10 15:43:31 jsing Exp $ */
+/* $OpenBSD: s23_clnt.c,v 1.37 2015/03/27 12:29:54 jsing Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -176,7 +176,6 @@ ssl23_get_client_method(int ver)
 int
 ssl23_connect(SSL *s)
 {
-	BUF_MEM *buf = NULL;
 	void (*cb)(const SSL *ssl, int type, int val) = NULL;
 	int ret = -1;
 	int new_state, state;
@@ -214,24 +213,14 @@ ssl23_connect(SSL *s)
 			/* s->version=TLS1_VERSION; */
 			s->type = SSL_ST_CONNECT;
 
-			if (s->init_buf == NULL) {
-				if ((buf = BUF_MEM_new()) == NULL) {
-					ret = -1;
-					goto end;
-				}
-				if (!BUF_MEM_grow(buf, SSL3_RT_MAX_PLAIN_LENGTH)) {
-					ret = -1;
-					goto end;
-				}
-				s->init_buf = buf;
-				buf = NULL;
+			if (!ssl3_setup_init_buffer(s)) {
+				ret = -1;
+				goto end;
 			}
-
 			if (!ssl3_setup_buffers(s)) {
 				ret = -1;
 				goto end;
 			}
-
 			if (!ssl3_init_finished_mac(s)) {
 				ret = -1;
 				goto end;
@@ -280,12 +269,12 @@ ssl23_connect(SSL *s)
 			s->state = new_state;
 		}
 	}
+
 end:
 	s->in_handshake--;
-	if (buf != NULL)
-		BUF_MEM_free(buf);
 	if (cb != NULL)
 		cb(s, SSL_CB_CONNECT_EXIT, ret);
+
 	return (ret);
 }
 
@@ -369,16 +358,6 @@ ssl23_client_hello(SSL *s)
 			    SSL_R_NO_CIPHERS_AVAILABLE);
 			return -1;
 		}
-#ifdef OPENSSL_MAX_TLS1_2_CIPHER_LENGTH
-		/*
-		 * Some servers hang if client hello > 256 bytes
-		 * as hack workaround chop number of supported ciphers
-		 * to keep it well below this if we use TLS v1.2
-		 */
-		if (TLS1_get_version(s) >= TLS1_2_VERSION &&
-		    i > OPENSSL_MAX_TLS1_2_CIPHER_LENGTH)
-			i = OPENSSL_MAX_TLS1_2_CIPHER_LENGTH & ~1;
-#endif
 		s2n(i, p);
 		p += i;
 
