@@ -1,4 +1,4 @@
-/* $OpenBSD: s3_both.c,v 1.37 2014/12/14 21:49:29 bcook Exp $ */
+/* $OpenBSD: s3_both.c,v 1.38 2015/03/27 12:29:54 jsing Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -450,20 +450,6 @@ ssl3_get_message(SSL *s, int st1, int stn, int mt, long max, int *ok)
 			SSLerr(SSL_F_SSL3_GET_MESSAGE, SSL_R_UNEXPECTED_MESSAGE);
 			goto f_err;
 		}
-		if ((mt < 0) && (*p == SSL3_MT_CLIENT_HELLO) &&
-		    (st1 == SSL3_ST_SR_CERT_A) && (stn == SSL3_ST_SR_CERT_B)) {
-			/* At this point we have got an MS SGC second client
-			 * hello (maybe we should always allow the client to
-			 * start a new handshake?). We need to restart the mac.
-			 * Don't increment {num,total}_renegotiations because
-			 * we have not completed the handshake. */
-			if (!ssl3_init_finished_mac(s)) {
-				SSLerr(SSL_F_SSL3_GET_MESSAGE,
-				    ERR_R_MALLOC_FAILURE);
-				goto err;
-			}
-		}
-
 		s->s3->tmp.message_type= *(p++);
 
 		n2l3(p, l);
